If you use SNCosmo for work presented in a publication, you can include a citation to the code. See http://dx.doi.org/10.5281/zenodo.11938 for citation styles.

A BibTeX entry for LaTeX users is:
```
@article{Barbary:11938,
      author        = "Barbary, Kyle",
      title         = "{sncosmo v0.4.2}",
      month         = "Apr",
      year          = "2014",
      doi           = "{10.5281/zenodo.11938}",
      url           = "{http://dx.doi.org/10.5281/zenodo.11938}",
}
```